/********************************************************************************
** Form generated from reading UI file 'kbetterthankdialogbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KBETTERTHANKDIALOGBASE_H
#define UI_KBETTERTHANKDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KBetterThanKDialogBase
{
public:
    QGridLayout *gridLayout;
    QLabel *_label;
    QSpacerItem *spacer1;
    QHBoxLayout *hboxLayout;
    QPushButton *_allowOnce;
    QPushButton *_allowAlways;
    QPushButton *_deny;
    QPushButton *_denyForever;
    QSpacerItem *spacer2;

    void setupUi(QDialog *KBetterThanKDialogBase)
    {
        if (KBetterThanKDialogBase->objectName().isEmpty())
            KBetterThanKDialogBase->setObjectName("KBetterThanKDialogBase");
        KBetterThanKDialogBase->resize(479, 109);
        gridLayout = new QGridLayout(KBetterThanKDialogBase);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QGridLayout::SetFixedSize);
        _label = new QLabel(KBetterThanKDialogBase);
        _label->setObjectName("_label");

        gridLayout->addWidget(_label, 0, 0, 1, 3);

        spacer1 = new QSpacerItem(41, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer1, 1, 2, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        _allowOnce = new QPushButton(KBetterThanKDialogBase);
        _allowOnce->setObjectName("_allowOnce");

        hboxLayout->addWidget(_allowOnce);

        _allowAlways = new QPushButton(KBetterThanKDialogBase);
        _allowAlways->setObjectName("_allowAlways");

        hboxLayout->addWidget(_allowAlways);

        _deny = new QPushButton(KBetterThanKDialogBase);
        _deny->setObjectName("_deny");

        hboxLayout->addWidget(_deny);

        _denyForever = new QPushButton(KBetterThanKDialogBase);
        _denyForever->setObjectName("_denyForever");

        hboxLayout->addWidget(_denyForever);


        gridLayout->addLayout(hboxLayout, 1, 1, 1, 1);

        spacer2 = new QSpacerItem(61, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer2, 1, 0, 1, 1);


        retranslateUi(KBetterThanKDialogBase);

        _allowOnce->setDefault(true);


        QMetaObject::connectSlotsByName(KBetterThanKDialogBase);
    } // setupUi

    void retranslateUi(QDialog *KBetterThanKDialogBase)
    {
        _allowOnce->setText(tr2i18n("&Replace", nullptr));
        _allowAlways->setText(tr2i18n("Replace &All", nullptr));
        _deny->setText(tr2i18n("&Skip", nullptr));
        _denyForever->setText(tr2i18n("Skip A&ll", nullptr));
        (void)KBetterThanKDialogBase;
    } // retranslateUi

};

namespace Ui {
    class KBetterThanKDialogBase: public Ui_KBetterThanKDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KBETTERTHANKDIALOGBASE_H

