/********************************************************************************
** Form generated from reading UI file 'applicationsmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPLICATIONSMANAGER_H
#define UI_APPLICATIONSMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "authorizedapplicationstable.h"
#include "connectedapplicationstable.h"

QT_BEGIN_NAMESPACE

class Ui_ApplicationsManager
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    ConnectedApplicationsTable *_connectedApps;
    QLabel *label_2;
    AuthorizedApplicationsTable *_authorizedApps;

    void setupUi(QWidget *ApplicationsManager)
    {
        if (ApplicationsManager->objectName().isEmpty())
            ApplicationsManager->setObjectName("ApplicationsManager");
        ApplicationsManager->resize(620, 458);
        verticalLayout = new QVBoxLayout(ApplicationsManager);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(ApplicationsManager);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        _connectedApps = new ConnectedApplicationsTable(ApplicationsManager);
        _connectedApps->setObjectName("_connectedApps");
        _connectedApps->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        _connectedApps->setProperty("showDropIndicator", QVariant(false));
        _connectedApps->setDragDropOverwriteMode(false);
        _connectedApps->setAlternatingRowColors(true);
        _connectedApps->setSelectionMode(QAbstractItemView::SingleSelection);
        _connectedApps->setSelectionBehavior(QAbstractItemView::SelectRows);
        _connectedApps->setShowGrid(false);
        _connectedApps->setWordWrap(false);
        _connectedApps->horizontalHeader()->setVisible(false);
        _connectedApps->horizontalHeader()->setStretchLastSection(true);
        _connectedApps->verticalHeader()->setVisible(false);
        _connectedApps->verticalHeader()->setStretchLastSection(false);

        verticalLayout->addWidget(_connectedApps);

        label_2 = new QLabel(ApplicationsManager);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        _authorizedApps = new AuthorizedApplicationsTable(ApplicationsManager);
        _authorizedApps->setObjectName("_authorizedApps");
        _authorizedApps->setProperty("showDropIndicator", QVariant(false));
        _authorizedApps->setDragDropOverwriteMode(false);
        _authorizedApps->setAlternatingRowColors(true);
        _authorizedApps->setSelectionMode(QAbstractItemView::SingleSelection);
        _authorizedApps->setSelectionBehavior(QAbstractItemView::SelectRows);
        _authorizedApps->setShowGrid(false);
        _authorizedApps->horizontalHeader()->setVisible(false);
        _authorizedApps->horizontalHeader()->setStretchLastSection(true);
        _authorizedApps->verticalHeader()->setVisible(false);

        verticalLayout->addWidget(_authorizedApps);


        retranslateUi(ApplicationsManager);

        QMetaObject::connectSlotsByName(ApplicationsManager);
    } // setupUi

    void retranslateUi(QWidget *ApplicationsManager)
    {
        label->setText(tr2i18n("These applications are currently connected to this wallet:", nullptr));
        label_2->setText(tr2i18n("These applications are authorized to access this wallet:", nullptr));
        (void)ApplicationsManager;
    } // retranslateUi

};

namespace Ui {
    class ApplicationsManager: public Ui_ApplicationsManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // APPLICATIONSMANAGER_H

