/********************************************************************************
** Form generated from reading UI file 'walletwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WALLETWIDGET_H
#define UI_WALLETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"
#include "kwhexview.h"
#include "kwtextedit.h"

QT_BEGIN_NAMESPACE

class Ui_WalletWidget
{
public:
    QGridLayout *gridLayout;
    QSplitter *_splitter;
    QFrame *_entryListFrame;
    QWidget *layout3;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *hboxLayout;
    QLabel *_iconTitle;
    QLabel *_entryTitle;
    KSqueezedTextLabel *_entryName;
    QStackedWidget *_entryStack;
    QWidget *page1;
    QWidget *page2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QToolButton *_hideContents;
    QSpacerItem *horizontalSpacer_5;
    KWTextEdit *_passwordValue;
    QWidget *page3;
    QWidget *binaryPage;
    QVBoxLayout *verticalLayout;
    QCheckBox *_binaryViewShow;
    KWHexView *_binaryView;
    QSpacerItem *verticalSpacer;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *_showContents;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer;
    QPushButton *_undoChanges;
    QPushButton *_saveChanges;

    void setupUi(QWidget *WalletWidget)
    {
        if (WalletWidget->objectName().isEmpty())
            WalletWidget->setObjectName("WalletWidget");
        WalletWidget->resize(482, 407);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(WalletWidget->sizePolicy().hasHeightForWidth());
        WalletWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(WalletWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        _splitter = new QSplitter(WalletWidget);
        _splitter->setObjectName("_splitter");
        sizePolicy.setHeightForWidth(_splitter->sizePolicy().hasHeightForWidth());
        _splitter->setSizePolicy(sizePolicy);
        _splitter->setOrientation(Qt::Horizontal);
        _splitter->setOpaqueResize(true);
        _splitter->setChildrenCollapsible(false);
        _entryListFrame = new QFrame(_splitter);
        _entryListFrame->setObjectName("_entryListFrame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(_entryListFrame->sizePolicy().hasHeightForWidth());
        _entryListFrame->setSizePolicy(sizePolicy1);
        _entryListFrame->setFrameShape(QFrame::NoFrame);
        _entryListFrame->setFrameShadow(QFrame::Plain);
        _splitter->addWidget(_entryListFrame);
        layout3 = new QWidget(_splitter);
        layout3->setObjectName("layout3");
        verticalLayout_4 = new QVBoxLayout(layout3);
        verticalLayout_4->setSpacing(0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(6);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(6, 6, 6, 0);
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        _iconTitle = new QLabel(layout3);
        _iconTitle->setObjectName("_iconTitle");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(_iconTitle->sizePolicy().hasHeightForWidth());
        _iconTitle->setSizePolicy(sizePolicy2);
        _iconTitle->setWordWrap(false);

        hboxLayout->addWidget(_iconTitle);

        _entryTitle = new QLabel(layout3);
        _entryTitle->setObjectName("_entryTitle");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(_entryTitle->sizePolicy().hasHeightForWidth());
        _entryTitle->setSizePolicy(sizePolicy3);
        QFont font;
        font.setBold(true);
        _entryTitle->setFont(font);
        _entryTitle->setTextFormat(Qt::RichText);
        _entryTitle->setAlignment(Qt::AlignVCenter);
        _entryTitle->setWordWrap(false);

        hboxLayout->addWidget(_entryTitle);


        verticalLayout_5->addLayout(hboxLayout);

        _entryName = new KSqueezedTextLabel(layout3);
        _entryName->setObjectName("_entryName");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(_entryName->sizePolicy().hasHeightForWidth());
        _entryName->setSizePolicy(sizePolicy4);
        _entryName->setTextFormat(Qt::PlainText);

        verticalLayout_5->addWidget(_entryName);

        _entryStack = new QStackedWidget(layout3);
        _entryStack->setObjectName("_entryStack");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(1);
        sizePolicy5.setHeightForWidth(_entryStack->sizePolicy().hasHeightForWidth());
        _entryStack->setSizePolicy(sizePolicy5);
        page1 = new QWidget();
        page1->setObjectName("page1");
        _entryStack->addWidget(page1);
        page2 = new QWidget();
        page2->setObjectName("page2");
        verticalLayout_3 = new QVBoxLayout(page2);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        _hideContents = new QToolButton(page2);
        _hideContents->setObjectName("_hideContents");
        _hideContents->setPopupMode(QToolButton::DelayedPopup);
        _hideContents->setToolButtonStyle(Qt::ToolButtonTextOnly);
        _hideContents->setArrowType(Qt::DownArrow);

        horizontalLayout_3->addWidget(_hideContents);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);


        verticalLayout_3->addLayout(horizontalLayout_3);

        _passwordValue = new KWTextEdit(page2);
        _passwordValue->setObjectName("_passwordValue");
        _passwordValue->setAcceptRichText(false);

        verticalLayout_3->addWidget(_passwordValue);

        _entryStack->addWidget(page2);
        page3 = new QWidget();
        page3->setObjectName("page3");
        _entryStack->addWidget(page3);
        binaryPage = new QWidget();
        binaryPage->setObjectName("binaryPage");
        verticalLayout = new QVBoxLayout(binaryPage);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        _binaryViewShow = new QCheckBox(binaryPage);
        _binaryViewShow->setObjectName("_binaryViewShow");
        _binaryViewShow->setChecked(true);

        verticalLayout->addWidget(_binaryViewShow);

        _binaryView = new KWHexView(binaryPage);
        _binaryView->setObjectName("_binaryView");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(1);
        sizePolicy6.setHeightForWidth(_binaryView->sizePolicy().hasHeightForWidth());
        _binaryView->setSizePolicy(sizePolicy6);
        _binaryView->setReadOnly(true);

        verticalLayout->addWidget(_binaryView);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        _entryStack->addWidget(binaryPage);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_2 = new QVBoxLayout(page_2);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        _showContents = new QToolButton(page_2);
        _showContents->setObjectName("_showContents");
        _showContents->setToolButtonStyle(Qt::ToolButtonFollowStyle);
        _showContents->setArrowType(Qt::NoArrow);

        horizontalLayout_2->addWidget(_showContents);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);

        _entryStack->addWidget(page_2);

        verticalLayout_5->addWidget(_entryStack);


        verticalLayout_4->addLayout(verticalLayout_5);

        horizontalLayout_4 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        horizontalLayout_4->setSpacing(6);
#endif
        horizontalLayout_4->setContentsMargins(6, 6, 6, 6);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        _undoChanges = new QPushButton(layout3);
        _undoChanges->setObjectName("_undoChanges");
        _undoChanges->setEnabled(false);

        horizontalLayout_4->addWidget(_undoChanges);

        _saveChanges = new QPushButton(layout3);
        _saveChanges->setObjectName("_saveChanges");
        _saveChanges->setEnabled(false);

        horizontalLayout_4->addWidget(_saveChanges);


        verticalLayout_4->addLayout(horizontalLayout_4);

        _splitter->addWidget(layout3);

        gridLayout->addWidget(_splitter, 0, 0, 1, 1);


        retranslateUi(WalletWidget);
        QObject::connect(_binaryViewShow, SIGNAL(toggled(bool)), _binaryView, SLOT(setVisible(bool)));

        QMetaObject::connectSlotsByName(WalletWidget);
    } // setupUi

    void retranslateUi(QWidget *WalletWidget)
    {
        _iconTitle->setText(QString());
        _entryTitle->setText(QString());
        _hideContents->setText(tr2i18n("Hide &Contents", nullptr));
        _binaryViewShow->setText(tr2i18n("Show &Contents", nullptr));
        _showContents->setText(tr2i18n("Show &Contents", nullptr));
        _undoChanges->setText(tr2i18n("&Undo", nullptr));
        _saveChanges->setText(tr2i18n("&Save", nullptr));
        (void)WalletWidget;
    } // retranslateUi

};

namespace Ui {
    class WalletWidget: public Ui_WalletWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WALLETWIDGET_H

