/****************************************************************************
** Meta object code from reading C++ file 'kwalleteditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwalletmanager-26.08.0/src/manager/kwalleteditor.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalleteditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KWalletEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletEditor::qt_create_metaobjectdata<qt_meta_tag_ZN13KWalletEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletEditor",
        "enableWalletActions",
        "",
        "enable",
        "enableFolderActions",
        "enableContextFolderActions",
        "walletClosed",
        "createFolder",
        "deleteFolder",
        "updateFolderList",
        "checkEntries",
        "entrySelectionChanged",
        "QTreeWidgetItem*",
        "item",
        "listItemChanged",
        "column",
        "listContextMenuRequested",
        "QPoint",
        "pos",
        "updateEntries",
        "folder",
        "newEntry",
        "renameEntry",
        "deleteEntry",
        "entryEditted",
        "restoreEntry",
        "saveEntry",
        "changePassword",
        "walletOpened",
        "success",
        "hidePasswordContents",
        "showPasswordContents",
        "showHideMapEditorValue",
        "show",
        "exportXML",
        "importXML",
        "importWallet",
        "copyPassword",
        "onSearchTextChanged",
        "onAlwaysShowContents",
        "onAlwaysHideContents"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enableWalletActions'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'enableFolderActions'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'enableContextFolderActions'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'walletClosed'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createFolder'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteFolder'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateFolderList'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'updateFolderList'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'entrySelectionChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'listItemChanged'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { QMetaType::Int, 15 },
        }}),
        // Slot 'listContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'updateEntries'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'newEntry'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameEntry'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteEntry'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'entryEditted'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'restoreEntry'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveEntry'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changePassword'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'walletOpened'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'hidePasswordContents'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showPasswordContents'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showHideMapEditorValue'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'exportXML'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importXML'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importWallet'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyPassword'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSearchTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'onAlwaysShowContents'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onAlwaysHideContents'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KWalletEditor, qt_meta_tag_ZN13KWalletEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWalletEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KWalletEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KWalletEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KWalletEditorE_t>.metaTypes,
    nullptr
} };

void KWalletEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enableWalletActions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->enableFolderActions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->enableContextFolderActions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->walletClosed(); break;
        case 4: _t->createFolder(); break;
        case 5: _t->deleteFolder(); break;
        case 6: _t->updateFolderList((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->updateFolderList(); break;
        case 8: _t->entrySelectionChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 9: _t->listItemChanged((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->listContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 11: _t->updateEntries((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->newEntry(); break;
        case 13: _t->renameEntry(); break;
        case 14: _t->deleteEntry(); break;
        case 15: _t->entryEditted(); break;
        case 16: _t->restoreEntry(); break;
        case 17: _t->saveEntry(); break;
        case 18: _t->changePassword(); break;
        case 19: _t->walletOpened((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->hidePasswordContents(); break;
        case 21: _t->showPasswordContents(); break;
        case 22: _t->showHideMapEditorValue((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->exportXML(); break;
        case 24: _t->importXML(); break;
        case 25: _t->importWallet(); break;
        case 26: _t->copyPassword(); break;
        case 27: _t->onSearchTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->onAlwaysShowContents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->onAlwaysHideContents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KWalletEditor::*)(bool )>(_a, &KWalletEditor::enableWalletActions, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletEditor::*)(bool )>(_a, &KWalletEditor::enableFolderActions, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletEditor::*)(bool )>(_a, &KWalletEditor::enableContextFolderActions, 2))
            return;
    }
}

const QMetaObject *KWalletEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KWalletEditorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::WalletWidget"))
        return static_cast< Ui::WalletWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int KWalletEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void KWalletEditor::enableWalletActions(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KWalletEditor::enableFolderActions(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KWalletEditor::enableContextFolderActions(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
