/****************************************************************************
** Meta object code from reading C++ file 'kwalletmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwalletmanager-26.08.0/src/manager/kwalletmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KWalletManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletManager::qt_create_metaobjectdata<qt_meta_tag_ZN14KWalletManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletManager",
        "D-Bus Interface",
        "org.kde.kwallet.kwalletmanager",
        "createWallet",
        "",
        "deleteWallet",
        "closeWallet",
        "walletName",
        "changeWalletPassword",
        "openWallet",
        "openWalletFile",
        "path",
        "contextMenu",
        "QPoint",
        "pos",
        "walletCreated",
        "allWalletsClosed",
        "updateWalletDisplay",
        "aWalletWasOpened",
        "shuttingDown",
        "possiblyQuit",
        "editorClosed",
        "KXmlGuiWindow*",
        "e",
        "possiblyRescan",
        "app",
        "setupWallet",
        "closeAllWallets",
        "exportWallets",
        "importWallets",
        "beginConfiguration",
        "configUI"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createWallet'
        QtMocHelpers::SlotData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteWallet'
        QtMocHelpers::SlotData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeWallet'
        QtMocHelpers::SlotData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'changeWalletPassword'
        QtMocHelpers::SlotData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'openWallet'
        QtMocHelpers::SlotData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'openWalletFile'
        QtMocHelpers::SlotData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'contextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'walletCreated'
        QtMocHelpers::SlotData<void(const QString &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'allWalletsClosed'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'updateWalletDisplay'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'aWalletWasOpened'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'shuttingDown'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'possiblyQuit'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editorClosed'
        QtMocHelpers::SlotData<void(KXmlGuiWindow *)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'possiblyRescan'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(24, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 4 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'setupWallet'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeAllWallets'
        QtMocHelpers::SlotData<void()>(27, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportWallets'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importWallets'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'beginConfiguration'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configUI'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KWalletManager, qt_meta_tag_ZN14KWalletManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KWalletManager::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KWalletManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KWalletManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KWalletManagerE_t>.metaTypes,
    nullptr
} };

void KWalletManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createWallet(); break;
        case 1: _t->deleteWallet(); break;
        case 2: _t->closeWallet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->changeWalletPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->openWallet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->openWalletFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 7: _t->walletCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->allWalletsClosed(); break;
        case 9: _t->updateWalletDisplay(); break;
        case 10: _t->aWalletWasOpened(); break;
        case 11: _t->shuttingDown(); break;
        case 12: _t->possiblyQuit(); break;
        case 13: _t->editorClosed((*reinterpret_cast<std::add_pointer_t<KXmlGuiWindow*>>(_a[1]))); break;
        case 14: _t->possiblyRescan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->setupWallet(); break;
        case 16: _t->closeAllWallets(); break;
        case 17: _t->exportWallets(); break;
        case 18: _t->importWallets(); break;
        case 19: _t->beginConfiguration(); break;
        case 20: _t->configUI(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KXmlGuiWindow* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KWalletManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KWalletManagerE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KWalletManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
