/********************************************************************************
** Form generated from reading UI file 'walletconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WALLETCONFIGWIDGET_H
#define UI_WALLETCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcontextualhelpbutton.h"
#include "kseparator.h"

QT_BEGIN_NAMESPACE

class Ui_WalletConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget2;
    QWidget *tab1;
    QVBoxLayout *vboxLayout;
    QCheckBox *_enabled;
    KSeparator *kseparator;
    QGroupBox *groupBox2;
    QVBoxLayout *vboxLayout1;
    QFormLayout *formLayout;
    QLabel *closeWalletLabel;
    QCheckBox *_autoclose;
    QCheckBox *_screensaverLock;
    QCheckBox *_closeIdle;
    QSpinBox *_idleTime;
    QGroupBox *groupBox4;
    QGridLayout *gridLayout;
    QFormLayout *formLayout3;
    QCheckBox *_localWalletSelected;
    QHBoxLayout *horizontalLayout4;
    QComboBox *_localWallet;
    QPushButton *_newLocalWallet;
    QLabel *selectDefaultWalletLabel;
    QHBoxLayout *horizontalLayout3;
    QComboBox *_defaultWallet;
    QPushButton *_newWallet;
    QGroupBox *groupBox3;
    QVBoxLayout *verticalLayout_3;
    QFormLayout *formLayout2;
    QCheckBox *_launchManager;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer;
    QCheckBox *_autocloseManager;
    QGroupBox *groupBox5;
    QVBoxLayout *vboxLayout2;
    QFormLayout *formLayout4;
    QHBoxLayout *horizontalLayout5;
    QCheckBox *_secretServiceAPI;
    KContextualHelpButton *kcontextualhelpbutton;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QWidget *tab2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *_openPrompt;
    QTreeWidget *_accessList;
    KSeparator *kseparator2;
    QHBoxLayout *launchButtonBar;
    QSpacerItem *spacerItem2;
    QPushButton *_launch;

    void setupUi(QWidget *WalletConfigWidget)
    {
        if (WalletConfigWidget->objectName().isEmpty())
            WalletConfigWidget->setObjectName("WalletConfigWidget");
        WalletConfigWidget->resize(540, 620);
        verticalLayout = new QVBoxLayout(WalletConfigWidget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget2 = new QTabWidget(WalletConfigWidget);
        tabWidget2->setObjectName("tabWidget2");
        tabWidget2->setDocumentMode(true);
        tab1 = new QWidget();
        tab1->setObjectName("tab1");
        vboxLayout = new QVBoxLayout(tab1);
        vboxLayout->setObjectName("vboxLayout");
        _enabled = new QCheckBox(tab1);
        _enabled->setObjectName("_enabled");
        _enabled->setChecked(true);

        vboxLayout->addWidget(_enabled);

        kseparator = new KSeparator(tab1);
        kseparator->setObjectName("kseparator");

        vboxLayout->addWidget(kseparator);

        groupBox2 = new QGroupBox(tab1);
        groupBox2->setObjectName("groupBox2");
        groupBox2->setFlat(true);
        vboxLayout1 = new QVBoxLayout(groupBox2);
        vboxLayout1->setObjectName("vboxLayout1");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setLabelAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        closeWalletLabel = new QLabel(groupBox2);
        closeWalletLabel->setObjectName("closeWalletLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, closeWalletLabel);

        _autoclose = new QCheckBox(groupBox2);
        _autoclose->setObjectName("_autoclose");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, _autoclose);

        _screensaverLock = new QCheckBox(groupBox2);
        _screensaverLock->setObjectName("_screensaverLock");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, _screensaverLock);

        _closeIdle = new QCheckBox(groupBox2);
        _closeIdle->setObjectName("_closeIdle");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, _closeIdle);

        _idleTime = new QSpinBox(groupBox2);
        _idleTime->setObjectName("_idleTime");
        _idleTime->setEnabled(false);
        _idleTime->setMinimumSize(QSize(250, 0));
        _idleTime->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);
        _idleTime->setMinimum(1);
        _idleTime->setMaximum(999);
        _idleTime->setSingleStep(5);
        _idleTime->setValue(10);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, _idleTime);


        vboxLayout1->addLayout(formLayout);


        vboxLayout->addWidget(groupBox2);

        groupBox4 = new QGroupBox(tab1);
        groupBox4->setObjectName("groupBox4");
        groupBox4->setFlat(true);
        gridLayout = new QGridLayout(groupBox4);
        gridLayout->setObjectName("gridLayout");
        formLayout3 = new QFormLayout();
        formLayout3->setObjectName("formLayout3");
        formLayout3->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::ExpandingFieldsGrow);
        formLayout3->setLabelAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        formLayout3->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        _localWalletSelected = new QCheckBox(groupBox4);
        _localWalletSelected->setObjectName("_localWalletSelected");

        formLayout3->setWidget(1, QFormLayout::ItemRole::FieldRole, _localWalletSelected);

        horizontalLayout4 = new QHBoxLayout();
        horizontalLayout4->setObjectName("horizontalLayout4");
        _localWallet = new QComboBox(groupBox4);
        _localWallet->setObjectName("_localWallet");
        _localWallet->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(_localWallet->sizePolicy().hasHeightForWidth());
        _localWallet->setSizePolicy(sizePolicy);
        _localWallet->setMinimumSize(QSize(300, 0));

        horizontalLayout4->addWidget(_localWallet);

        _newLocalWallet = new QPushButton(groupBox4);
        _newLocalWallet->setObjectName("_newLocalWallet");
        _newLocalWallet->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(_newLocalWallet->sizePolicy().hasHeightForWidth());
        _newLocalWallet->setSizePolicy(sizePolicy1);

        horizontalLayout4->addWidget(_newLocalWallet);


        formLayout3->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout4);

        selectDefaultWalletLabel = new QLabel(groupBox4);
        selectDefaultWalletLabel->setObjectName("selectDefaultWalletLabel");

        formLayout3->setWidget(0, QFormLayout::ItemRole::LabelRole, selectDefaultWalletLabel);

        horizontalLayout3 = new QHBoxLayout();
        horizontalLayout3->setObjectName("horizontalLayout3");
        _defaultWallet = new QComboBox(groupBox4);
        _defaultWallet->setObjectName("_defaultWallet");
        sizePolicy.setHeightForWidth(_defaultWallet->sizePolicy().hasHeightForWidth());
        _defaultWallet->setSizePolicy(sizePolicy);
        _defaultWallet->setMinimumSize(QSize(300, 0));

        horizontalLayout3->addWidget(_defaultWallet);

        _newWallet = new QPushButton(groupBox4);
        _newWallet->setObjectName("_newWallet");
        sizePolicy1.setHeightForWidth(_newWallet->sizePolicy().hasHeightForWidth());
        _newWallet->setSizePolicy(sizePolicy1);

        horizontalLayout3->addWidget(_newWallet);


        formLayout3->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout3);


        gridLayout->addLayout(formLayout3, 0, 0, 1, 1);


        vboxLayout->addWidget(groupBox4);

        groupBox3 = new QGroupBox(tab1);
        groupBox3->setObjectName("groupBox3");
        groupBox3->setFlat(true);
        verticalLayout_3 = new QVBoxLayout(groupBox3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        formLayout2 = new QFormLayout();
        formLayout2->setObjectName("formLayout2");
        formLayout2->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        _launchManager = new QCheckBox(groupBox3);
        _launchManager->setObjectName("_launchManager");
        _launchManager->setChecked(true);

        formLayout2->setWidget(0, QFormLayout::ItemRole::FieldRole, _launchManager);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        _autocloseManager = new QCheckBox(groupBox3);
        _autocloseManager->setObjectName("_autocloseManager");

        horizontalLayout_3->addWidget(_autocloseManager);


        formLayout2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);


        verticalLayout_3->addLayout(formLayout2);


        vboxLayout->addWidget(groupBox3);

        groupBox5 = new QGroupBox(tab1);
        groupBox5->setObjectName("groupBox5");
        groupBox5->setFlat(true);
        vboxLayout2 = new QVBoxLayout(groupBox5);
        vboxLayout2->setObjectName("vboxLayout2");
        formLayout4 = new QFormLayout();
        formLayout4->setObjectName("formLayout4");
        formLayout4->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        horizontalLayout5 = new QHBoxLayout();
        horizontalLayout5->setSpacing(0);
        horizontalLayout5->setObjectName("horizontalLayout5");
        _secretServiceAPI = new QCheckBox(groupBox5);
        _secretServiceAPI->setObjectName("_secretServiceAPI");
        _secretServiceAPI->setChecked(true);

        horizontalLayout5->addWidget(_secretServiceAPI);

        kcontextualhelpbutton = new KContextualHelpButton(groupBox5);
        kcontextualhelpbutton->setObjectName("kcontextualhelpbutton");

        horizontalLayout5->addWidget(kcontextualhelpbutton);


        formLayout4->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout5);


        vboxLayout2->addLayout(formLayout4);

        spacerItem = new QSpacerItem(20, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        vboxLayout2->addItem(spacerItem);


        vboxLayout->addWidget(groupBox5);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);

        tabWidget2->addTab(tab1, QString());
        tab2 = new QWidget();
        tab2->setObjectName("tab2");
        verticalLayout_2 = new QVBoxLayout(tab2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        _openPrompt = new QCheckBox(tab2);
        _openPrompt->setObjectName("_openPrompt");
        _openPrompt->setChecked(true);

        verticalLayout_2->addWidget(_openPrompt);

        _accessList = new QTreeWidget(tab2);
        _accessList->setObjectName("_accessList");
        _accessList->setRootIsDecorated(true);

        verticalLayout_2->addWidget(_accessList);

        tabWidget2->addTab(tab2, QString());

        verticalLayout->addWidget(tabWidget2);

        kseparator2 = new KSeparator(WalletConfigWidget);
        kseparator2->setObjectName("kseparator2");

        verticalLayout->addWidget(kseparator2);

        launchButtonBar = new QHBoxLayout();
        launchButtonBar->setObjectName("launchButtonBar");
        spacerItem2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        launchButtonBar->addItem(spacerItem2);

        _launch = new QPushButton(WalletConfigWidget);
        _launch->setObjectName("_launch");

        launchButtonBar->addWidget(_launch);


        verticalLayout->addLayout(launchButtonBar);


        retranslateUi(WalletConfigWidget);
        QObject::connect(_localWalletSelected, &QCheckBox::toggled, _newLocalWallet, &QPushButton::setEnabled);
        QObject::connect(_localWalletSelected, &QCheckBox::toggled, _localWallet, &QComboBox::setEnabled);
        QObject::connect(_closeIdle, &QCheckBox::toggled, _idleTime, &QSpinBox::setEnabled);
        QObject::connect(_enabled, &QCheckBox::toggled, groupBox2, &QGroupBox::setEnabled);
        QObject::connect(_enabled, &QCheckBox::toggled, groupBox4, &QGroupBox::setEnabled);
        QObject::connect(_enabled, &QCheckBox::toggled, groupBox3, &QGroupBox::setEnabled);
        QObject::connect(_enabled, &QCheckBox::toggled, groupBox5, &QGroupBox::setEnabled);
        QObject::connect(_closeIdle, &QCheckBox::toggled, _idleTime, &QSpinBox::setEnabled);
        QObject::connect(_launchManager, &QCheckBox::toggled, _autocloseManager, &QCheckBox::setEnabled);

        tabWidget2->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(WalletConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *WalletConfigWidget)
    {
#if QT_CONFIG(whatsthis)
        _enabled->setWhatsThis(tr2i18n("<p>The wallet subsystem provides a convenient and secure way to manage all your passwords. This option specifies whether or not you want to use it.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        _enabled->setText(tr2i18n("&Enable the KDE wallet subsystem", nullptr));
#if QT_CONFIG(whatsthis)
        groupBox2->setWhatsThis(tr2i18n("It is best to close your wallets when you are not using them to prevent others from viewing or using them.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox2->setTitle(tr2i18n("Close Behavior", nullptr));
        closeWalletLabel->setText(tr2i18n("Close wallet:", nullptr));
#if QT_CONFIG(whatsthis)
        _autoclose->setWhatsThis(tr2i18n("<p><b>Close wallet as soon as applications that use it have stopped.</b><br>Note that your wallet will only be closed when all applications that use it have stopped.<br>When a wallet is closed the password is needed to access it again.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        _autoclose->setText(tr2i18n("When last application stops using it", nullptr));
#if QT_CONFIG(whatsthis)
        _screensaverLock->setWhatsThis(tr2i18n("<p><b>Close wallet as soon as the screensaver starts.</b><br>When a wallet is closed the password is needed to access it again.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        _screensaverLock->setText(tr2i18n("When screensaver starts", nullptr));
#if QT_CONFIG(whatsthis)
        _closeIdle->setWhatsThis(tr2i18n("<p><b>Close wallet after a period of inactivity.</b><br>When a wallet is closed the password is needed to access it again.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        _closeIdle->setText(tr2i18n("When unused for:", nullptr));
#if QT_CONFIG(whatsthis)
        _idleTime->setWhatsThis(tr2i18n("<p><b>Close wallet after a period of inactivity.</b><br>When a wallet is closed the password is needed to access it again.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        _idleTime->setSuffix(tr2i18n(" minutes", nullptr));
        groupBox4->setTitle(tr2i18n("Automatic Wallet Selection", nullptr));
        _localWalletSelected->setText(tr2i18n("Use different default wallet for local passwords", nullptr));
        _newLocalWallet->setText(tr2i18n("New...", nullptr));
        selectDefaultWalletLabel->setText(tr2i18n("Default wallet:", nullptr));
        _newWallet->setText(tr2i18n("New...", nullptr));
        groupBox3->setTitle(tr2i18n("Wallet Manager", nullptr));
        _launchManager->setText(tr2i18n("Show manager in system tray", nullptr));
        _autocloseManager->setText(tr2i18n("Hide system tray icon when last wallet closes", nullptr));
        groupBox5->setTitle(tr2i18n("Secret Service", nullptr));
        _secretServiceAPI->setText(tr2i18n("Use &KWallet for the Secret Service interface", nullptr));
        kcontextualhelpbutton->setContextualHelpText(tr2i18n("The Secret Service interface lets applications store passwords and other confidential data. Disable this to allow third-party wallet services such as KeePassXC or GNOME Keyring to manage it instead.", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab1), tr2i18n("Wallet Preferences", nullptr));
        _openPrompt->setText(tr2i18n("&Prompt when an application accesses a wallet", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = _accessList->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Policy", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Application", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Wallet", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tab2), tr2i18n("Access Control", nullptr));
        _launch->setText(tr2i18n("&Launch Wallet Manager", nullptr));
        (void)WalletConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class WalletConfigWidget: public Ui_WalletConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WALLETCONFIGWIDGET_H

